Différents modes
================
*Outils → Options → Général* permet de régler l'interface utilisateur de turcar selon un des trois modes différents.


Mode ordinaire
--------------

C'est le mode par défaut. Il n'y a pas grand-chose à en dire.


Mode simple
-----------

Dans ce mode les menus sont cachés et la vue des Variables est automatiquement ouverte.
On peut utiliser un petit lien dans le coin en haut à droite pour revenir au mode ordinaire.


Mode expert
-----------

Ce mode ressemble beaucoup au mode ordinaire, mais offre quelques fonctionnalités de plus, utiles pour enseigner.

* Le menu Afficher dispose d'un item *Plein écran* pour mettre turcar en mode plein écran.
* Quand on double-clique sur l'onglet d'un éditeur ou d'une vue, cela permet de la maximiser ; on peut revenir à la taille d'origine en double-cliquant l'onglet à nouveau.
* Le menu des Outils gagne un item de plus *Ouvrir et rejouer ...* qui permet de rejouer les journaux d'action de l'utilisateur.


